AFRL labeling general (sarpy.annotation.afrl_elements.blocks)
=============================================================

.. automodule:: sarpy.annotation.afrl_elements.blocks
    :members:
    :show-inheritance:
    :inherited-members:
